import * as FRAGS from "@thatopen/fragments";
import * as THREE from "three";
import * as OBC from "@thatopen/components";
/**
 * A renderer to determine a geometry visibility on screen
 */
export declare class GeometryCullerRenderer extends OBC.CullerRenderer {
    threshold: number;
    bboxThreshold: number;
    maxLostTime: number;
    maxHiddenTime: number;
    boxes: Map<number, FRAGS.Fragment>;
    private _staticGeometries;
    private readonly _geometry;
    private _material;
    readonly onViewUpdated: OBC.AsyncEvent<{
        toLoad: {
            [modelID: string]: Map<number, Set<number>>;
        };
        toRemove: {
            [modelID: string]: Set<number>;
        };
        toHide: {
            [modelID: string]: Set<number>;
        };
        toShow: {
            [modelID: string]: Set<number>;
        };
    }>;
    private _modelIDIndex;
    private _indexModelID;
    private _nextModelID;
    private _geometries;
    private _geometriesGroups;
    private _geometriesInMemory;
    private _intervalID;
    private codes;
    constructor(components: OBC.Components, world: OBC.World);
    dispose(): void;
    add(modelID: string, assets: OBC.StreamedAsset[], geometries: OBC.StreamedGeometries): void;
    remove(modelID: string): void;
    addFragment(modelID: string, geometryID: number, frag: FRAGS.Fragment): void;
    removeFragment(modelID: string, geometryID: number): void;
    setModelTransformation(modelID: string, transform: THREE.Matrix4): void;
    setVisibility(visible: boolean, modelID: string, geometryIDsAssetIDs: Map<number, Set<number>>): void;
    updateTransformations(modelID: string): void;
    addStaticGeometries(geometries: {
        [modelID: string]: Set<number>;
    }, culled?: boolean): Promise<void>;
    removeStaticGeometries(geometries: {
        [modelID: string]: Set<number>;
    }, culled?: boolean): void;
    cancel(items: {
        [modelID: string]: Set<number>;
    }): void;
    getBoundingBoxes(items: {
        [modelID: number]: Iterable<number>;
    }): FRAGS.FragmentsGroup;
    getInstanceID(assetID: number, geometryID: number): number;
    private setGeometryVisibility;
    private handleWorkerMessage;
    private handleLostGeometries;
    private createModelIndex;
}
