import * as THREE from "three";
import * as OBC from "@thatopen/components";
import { SimpleDimensionLine } from "../SimpleDimensionLine";
/**
 * A basic dimension tool to measure distances between 2 points in 3D and display a 3D symbol displaying the numeric value. 📕 [Tutorial](https://docs.thatopen.com/Tutorials/Components/Front/LengthMeasurement). 📘 [API](https://docs.thatopen.com/api/@thatopen/components-front/classes/LengthMeasurement).
 */
export declare class LengthMeasurement extends OBC.Component implements OBC.Createable, OBC.Hideable, OBC.Disposable, OBC.Updateable {
    /**
     * A unique identifier for the component.
     * This UUID is used to register the component within the Components system.
     */
    static readonly uuid: "2f9bcacf-18a9-4be6-a293-e898eae64ea1";
    /** {@link OBC.Disposable.onDisposed} */
    readonly onDisposed: OBC.Event<unknown>;
    /** {@link OBC.Updateable.onBeforeUpdate} */
    readonly onBeforeUpdate: OBC.Event<LengthMeasurement>;
    /** {@link OBC.Updateable.onAfterUpdate} */
    readonly onAfterUpdate: OBC.Event<LengthMeasurement>;
    readonly onCleaned: OBC.Event<null>;
    /** The minimum distance to force the dimension cursor to a vertex. */
    snapDistance: number;
    /**
     * A list of all the measurement elements created by this component.
     */
    list: SimpleDimensionLine[];
    /**
     * The world in which the angle measurements are performed.
     * This property is optional and can be set to null if no world is available.
     */
    world?: OBC.World;
    private _vertexPicker;
    private _lineMaterial;
    private _visible;
    private _enabled;
    /** Temporary variables for internal operations */
    private _temp;
    /** {@link OBC.Component.enabled} */
    get enabled(): boolean;
    /** {@link OBC.Component.enabled} */
    set enabled(value: boolean);
    /** {@link OBC.Hideable.visible} */
    get visible(): boolean;
    /** {@link OBC.Hideable.visible} */
    set visible(value: boolean);
    /**
     * Getter for the color of the dimension lines.
     * Returns the color of the line material used for the dimension lines.
     *
     */
    get color(): THREE.Color;
    /**
     * Setter for the color of the dimension lines.
     * Sets the color of the line material used for the dimension lines.
     *
     */
    set color(color: THREE.Color);
    constructor(components: OBC.Components);
    /** {@link OBC.Disposable.dispose} */
    dispose(): void;
    /** {@link OBC.Updateable.update} */
    update(_delta: number): Promise<void>;
    /**
     * Starts or finishes drawing a new dimension line.
     *
     * @param data - forces the dimension to be drawn on a plane. Use this if you are drawing
     * dimensions in floor plan navigation.
     */
    create: (data?: any) => void;
    /**
     * Creates a new dimension line between two given points.
     *
     * @param p1 - The start point of the dimension line.
     * @param p2 - The end point of the dimension line.
     *
     */
    createOnPoints(p1: THREE.Vector3, p2: THREE.Vector3): SimpleDimensionLine;
    /** {@link OBC.Createable.delete} */
    delete(): void;
    /**
     * Deletes a specific measurement from the list.
     *
     * @param measurement - The measurement to be deleted.
     *
     * @remarks
     * If the measurement does not exist in the list, no action is taken.
     *
     */
    deleteMeasurement(measurement: SimpleDimensionLine): Promise<void>;
    /** Deletes all the dimensions that have been previously created. */
    deleteAll(): void;
    /** {@link OBC.Createable.cancelCreation} */
    cancelCreation(): void;
    /** {@link OBC.Createable.endCreation} */
    endCreation(): void;
    private drawStart;
    private drawInProcess;
    private drawDimension;
    private getBoundingBoxes;
    private setupEvents;
    private onMouseMove;
    private onKeydown;
}
